==> phing_2.8.2+dfsg.orig.tar.gz: phing-2.8.2/tasks/system/condition/NotCondition.php <==
<?php
/*
 *  $Id: ef6fe783a698a1646e2c687c4cfa6c066129f6d7 $
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many individuals
 * and is licensed under the LGPL. For more information please see
 * <http://phing.info>.
 */

require_once 'phing/tasks/system/condition/ConditionBase.php';

/**
 * <not> condition.
 *
 * Evaluates to true if the single condition nested into it is false
 * and vice versa.
 *
 * @author    Andreas Aderhold <andi@binarycloud.com>
 * @copyright 2001,2002 THYRELL. All rights reserved
 * @version   $Id: ef6fe783a698a1646e2c687c4cfa6c066129f6d7 $
 * @access    public
 * @package   phing.tasks.system.condition
 */
class NotCondition extends ConditionBase implements Condition {

    function evaluate() {
        if ($this->countConditions() > 1) {
            throw new BuildException("You must not nest more than one condition into <not>");
        }
        if ($this->countConditions() < 1) {
            throw new BuildException("You must nest a condition into <not>");
        }
        $conds = $this->getIterator();
        return !$conds->current()->evaluate();
    }
}

==> phing_2.17.4.orig.tar.gz: phing-2.17.4/tasks/system/condition/NotCondition.php <==
<?php
/*
 *  $Id: 9bcbe1b79aee7edb15117fbde13481e5e7ec098a $
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many individuals
 * and is licensed under the LGPL. For more information please see
 * <http://phing.info>.
 */

require_once 'phing/tasks/system/condition/ConditionBase.php';

/**
 * <not> condition.
 *
 * Evaluates to true if the single condition nested into it is false
 * and vice versa.
 *
 * @author    Andreas Aderhold <andi@binarycloud.com>
 * @copyright 2001,2002 THYRELL. All rights reserved
 * @version   $Id: 9bcbe1b79aee7edb15117fbde13481e5e7ec098a $
 * @package   phing.tasks.system.condition
 */
class NotCondition extends ConditionBase implements Condition
{

    /**
     * @return bool
     * @throws BuildException
     */
    public function evaluate()
    {
        if ($this->countConditions() > 1) {
            throw new BuildException("You must not nest more than one condition into <not>");
        }
        if ($this->countConditions() < 1) {
            throw new BuildException("You must nest a condition into <not>");
        }
        $conds = $this->getIterator();

        return !$conds->current()->evaluate();
    }
}
